"use strict";

/* exported logger */

var ObjectWithListeners = require('../ObjectWithListeners');
var PanelControlElementType = require('./PanelControlElementType');

var logger = require('../logger');

function AbstractGuiElement(params) {
  ObjectWithListeners.call(this, params);

  var self = this;

  self.setElement(params.element);
  self.setMap(params.customMap);

  self._controlElements = [];

}

AbstractGuiElement.prototype = Object.create(ObjectWithListeners.prototype);
AbstractGuiElement.prototype.constructor = AbstractGuiElement;

AbstractGuiElement.prototype.setMap = function(map) {
  if (map === undefined || map === null) {
    throw new Error("map must be defined");
  }
  this._map = map;
};

AbstractGuiElement.prototype.getMap = function() {
  return this._map;
};

AbstractGuiElement.prototype.setElement = function(element) {
  if (element === undefined || element === null) {
    throw new Error("DOM Element must be defined");
  }
  this._element = element;
};

AbstractGuiElement.prototype.getElement = function() {
  return this._element;
};

AbstractGuiElement.prototype.setControlElement = function(type, element) {
  if (type === null || type === undefined) {
    throw new Error("Unknown controle element type");
  }
  if (PanelControlElementType[type] === undefined) {
    throw new Error("Unknown controle element type: " + type);
  }

  this._controlElements[type] = element;
};

AbstractGuiElement.prototype.getControlElement = function(type) {
  if (type === null || type === undefined) {
    throw new Error("Unknown controle element type");
  }
  if (PanelControlElementType[type] === undefined) {
    throw new Error("Unknown controle element type: " + type);
  }

  return this._controlElements[type];
};

module.exports = AbstractGuiElement;
