"use strict";

/* exported logger */

var Helper = require('../helper');

require("../mocha-config.js");

var MapContextMenu = require('../../../main/js/gui/MapContextMenu');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../logger');

describe('MapContextMenu', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it('constructor', function() {
    var map = helper.createCustomMap();

    new MapContextMenu({
      element : testDiv,
      customMap : map
    });

    assert.equal(logger.getWarnings().length, 0);
  });

  it('open comment dialog', function() {
    var map;
    return ServerConnector.getProject().then(function(project) {
      map = helper.createCustomMap(project);

      var contextMenu = new MapContextMenu({
        element : testDiv,
        customMap : map
      });
      map.setActiveSubmapId(map.getProject().getModel().getId());
      map.setActiveSubmapClickCoordinates(new google.maps.Point(2, 12));

      var handler = $($("a:contains('comment')", $(testDiv))[0]).data("handler");
      return handler();
    }).then(function() {
      map.destroy();
    });
  });

  it('start select mode', function() {
    var map;
    return ServerConnector.getProject().then(function(project) {
      map = helper.createCustomMap(project);

      var contextMenu = new MapContextMenu({
        element : testDiv,
        customMap : map
      });
      map.setActiveSubmapId(map.getProject().getModel().getId());
      map.setActiveSubmapClickCoordinates(new google.maps.Point(2, 12));

      assert.ok(!map.isDrawingOn());
      var handler = $($("a:contains('Select mode')", $(testDiv))[0]).data("handler");
      return handler();
    }).then(function() {
      assert.ok(map.isDrawingOn());
    });
  });

});
